#
# spec file for package plasma6-pa
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.14.0
%define qt6_version 6.8.0

%define rname plasma-pa
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %global _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           plasma6-pa
Version:        6.4.0
Release:        1.1
Summary:        The Plasma6 Volume Manager
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Declarative) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6PulseAudioQt)
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6Svg) >= %{kf6_version}
BuildRequires:  cmake(Plasma) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
# Used despite BUILD_TESTING=OFF...
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libpulse)
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       (pulseaudio-module-x11 or pipewire-pulseaudio)
# boo#1092871
Recommends:     (pulseaudio-module-gsettings if pulseaudio)
Supplements:    (plasma6-desktop and (pulseaudio or pipewire-pulseaudio))
Provides:       plasma5-pa = %{version}
Obsoletes:      plasma5-pa < %{version}
Obsoletes:      plasma5-pa-lang < %{version}
%if 0%{?suse_version} > 1500
Suggests:       pipewire-pulseaudio
%else
Suggests:       pulseaudio-module-x11
%endif

%description
A volume manager plasmoid superseding kmix.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name --with-html

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc %{_kf6_htmldir}/en/kcontrol/
%{_kf6_applicationsdir}/kcm_pulseaudio.desktop
%{_kf6_debugdir}/plasmapa.categories
%{_kf6_libdir}/libplasma-volume.so.*
%{_kf6_plugindir}/kf6/kded/audioshortcutsservice.so
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.volume.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_pulseaudio.so
%dir %{_kf6_qmldir}/org/kde/plasma/private
%{_kf6_qmldir}/org/kde/plasma/private/volume/

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kcontrol

%changelog
* Thu Jun 12 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.4.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.4.0
- Changes since 6.3.91:
  * Update version for new release 6.4.0
  * applet: don't freeze Plasma & don't auto-resize desktop widget
  * applet: be less aggressive about indicating currentIndex
  * applet: fix alignment in RtL
  * applet: indent simple label if other view has radio buttons
* Thu May 29 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.91
- Changes since 6.3.90:
  * Update version for new release 6.3.91
  * applet/ListItemBase: also indent mute button without radio button
  * applet: improve keyboard navigation and accessibility
  * applet/listitem: increase delegate-intenal vertical spacing
  * applet/ListItemBase: switch icon to view-more-symbolic
  * applet: fix and simplify arrow key navigation
  * applet: indent mute button in fullRepresentation
* Mon May 19 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.3.90
- Changes since 6.3.5:
  * update version for new release
  * applet: use section headers in listview (kde#503895)
  * VolumeFeedback: Use custom role for volume feedback
  * applet: size SmallToolButton correctly
  * ListItemBase: Force plain text format
  * StreamListItem: Show media.name if applicable (kde#453629)
  * Use new plasma_add_applet API
  * Show OSD when application starts using muted microphone
  * appiumtest: make applettest less flaky
  * applet: fix resetting wheel delta from previous scroll action
  * kcms: call OSDs OSDs
  * kded: Consult Bluez to get battery percentage
  * CI: Add linux-qt6-next build
  * applet: don't make inactive StackView pages initially visible
  * kcm: make inactive detection more robust (kde#496682)
  * Add xml/yaml linting
  * applet: remove broken chord keyboard shortcut
  * Add hamburger menu in plasma-pa applet (kde#497869)
  * Const'ify pointer
  * Add missing override/explicit keyword
  * Fix qml warnings
  * Use u"foo"_s
  * It compiles without deprecated methods
  * Remove unused #include <QtGlobal>
  * Add headers in qtc6
  * Use qCWarning(<foo>)
  * update version for new release
* Tue May  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.5
- Changes since 6.3.4:
  * update version for new release
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.3.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/6/6.3.4
- Changes since 6.3.3:
  * update version for new release
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
  * applet: don't make inactive StackView pages initially visible
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
  * Revert "Only show osd on global shortcuts or scrolling the applet" (kde#500129)
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
  * Only show osd on global shortcuts or scrolling the applet
  * kcm: make inactive detection more robust (kde#496682)
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * kded: Don't show default sink OSD when coming frm no sink
  * Made KDocTools optional
  * Add autogenerate debug category
  * Add missing include moc
  * listitemmenu: guard activePort against null
  * kcm: Fix speaker test layout for Pro-Audio profile (kde#495752)
  * KCM: Fix QML warnings
  * Update git blame ignore file
  * Reformat code with clang-format
  * rename: set correct device name upon reset (kde#494546)
  * fix text display for auto_null device (kde#494324)
  * Update PulseAudio-Qt to 1.6.0
  * update version for new release
  * kcm: validate percent input correctly (kde#420416)
  * rip out the name source changing
  * use description as per upstream recommendation (kde#487658)
  * applet: directly set switching sizes (kde#493042)
  * Port away from deprecated ""_qba
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
  * listitemmenu: guard activePort against null
  * kcm: Fix speaker test layout for Pro-Audio profile (kde#495752)
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * rename: set correct device name upon reset (kde#494546)
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
  * fix text display for auto_null device (kde#494324)
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * kcm: validate percent input correctly (kde#420416)
  * rip out the name source changing
  * use description as per upstream recommendation (kde#487658)
  * applet: directly set switching sizes (kde#493042)
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * allow user to rename devices and select a preferred name source (kde#487658,kde#491205,kde#488897)
  * implement UI tracking for the Context state
  * Remove virtual keyword when we use override
  * Modernize PulseObjectFilterModel
  * volumemonitor: don't crash when there is no pa_context
  * kcm/SpeakerTest: Fix the minimum layout for Mono channel (kde#476096)
  * applet: make Applications volume sliders respect Raise maximum volume
  * Don't install plasma-volume.so symlink
  * Set Maximum Volume to 150%% (kde#487508)
  * kcm/SpeakerTest: Close dialog when the tested device disconnects
  * KCM: rename "Balance" button for clarity (kde#487323)
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * volumemonitor: don't crash when there is no pa_context
  * kcm/SpeakerTest: Fix the minimum layout for Mono channel (kde#476096)
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * Don't install plasma-volume.so symlink
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * Set Maximum Volume to 150%% (kde#487508)
  * kcm/SpeakerTest: Close dialog when the tested device disconnects
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
  * Add URL to the metadata
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * applet: Fix hiddenTypes property
  * applet: fix unable to finetune slider (kde#479028)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * RC 1 version dep
  * add a version for dependencies so it does not break CI https://invent.kde.org/plasma/bluedevil/-/merge_requests/156
  * fix CI
  * applet: respect volumeStep setting in slider (kde#409325)
  * kcm/VolumeSlider: fix scroll (kde#459639)
  * streamrestore: workaround for notification volume (kde#473013)
  * kcm: adjust to changes in VolumeSlider
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Aug 25 2023 Christophe Marin <christophe@krop.fr>
- Init plasma6-pa
